@@ -17,7 +17,7 @@ use YAML::XS ();
 use File::Temp qw( tempdir );
 
 # ABSTRACT: Test Clustericious commands
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 
 our @EXPORT      = qw( extract_data mirror requires run_ok generate_port note_file clean_file create_symlink );
@@ -184,7 +184,8 @@ sub run_ok
   $tb->diag("    - execute failed: $error") if $exit == -1;
   $tb->diag("    - died from signal: " . ($exit & 128)) if $exit & 128;
 
-  Test::Clustericious::Command::Run->new(  
+  Test::Clustericious::Command::Run->new(
+    cmd => \@cmd,
     out => $out, err => $err, exit => $exit >> 8,
   );
 }
@@ -239,6 +240,7 @@ sub new
   bless \%args, $class;
 }
 
+sub cmd { @{ shift->{cmd} // [] } }
 sub out { shift->{out} }
 sub err { shift->{err} }
 sub exit { shift->{exit} }
@@ -249,6 +251,12 @@ sub exit_is
   $name //= "exit with $value";
   my $tb = __PACKAGE__->builder;
   $tb->is_eq($self->exit, $value, $name);
+  unless($self->exit == $value)
+  {
+    $tb->diag("[cmd]\n", join(' ', $self->cmd)) if $self->cmd;
+    $tb->diag("[out]\n", $self->out) if $self->out;
+    $tb->diag("[err]\n", $self->err) if $self->err;
+  }
   $self;
 }
 
@@ -335,7 +343,7 @@ Test::Clustericious::Command - Test Clustericious commands
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 SYNOPSIS
 
